pub enum BackendCmd {
Configure {
backend: String,
endpoint: Option<String>,
workspace_id: Option<String>,
initial_commit: bool,
no_initial_commit: bool,
},
Status,
}Expand description
Subcommands for px backend (deprecated: use px configure).
Variants
Configure
Configure the version-control backend.
After configuration, existing unversioned repositories in this PX home are offered an initial commit so their current filesystem state becomes the repository baseline (unless –no-initial-commit is given).
Fields
Status
Show the current version-control backend configuration.